import type { Selector, GetParamsFromSelectors, OutputSelector, EqualityFn, SelectorArray, SelectorResultArray } from './types';
export type { Selector, GetParamsFromSelectors, OutputSelector, EqualityFn, SelectorArray, SelectorResultArray, ParametricSelector } from './types';
export declare const defaultEqualityCheck: EqualityFn;
export declare function defaultMemoize<F extends (...args: any[]) => any>(func: F, equalityCheck?: EqualityFn): F;
export declare function createSelectorCreator(memoize: <F extends (...args: any[]) => any>(func: F) => F): CreateSelectorFunction;
export declare function createSelectorCreator<O1>(memoize: <F extends (...args: any[]) => any>(func: F, option1: O1) => F, option1: O1): CreateSelectorFunction;
export declare function createSelectorCreator<O1, O2>(memoize: <F extends (...args: any[]) => any>(func: F, option1: O1, option2: O2) => F, option1: O1, option2: O2): CreateSelectorFunction;
export declare function createSelectorCreator<O1, O2, O3>(memoize: <F extends (...args: any[]) => any>(func: F, option1: O1, option2: O2, option3: O3, ...rest: any[]) => F, option1: O1, option2: O2, option3: O3, ...rest: any[]): CreateSelectorFunction;
interface CreateSelectorFunction {
    <Selectors extends SelectorArray, Result>(...items: [
        ...Selectors,
        (...args: SelectorResultArray<Selectors>) => Result
    ]): OutputSelector<Selectors, Result, GetParamsFromSelectors<Selectors>, (...args: SelectorResultArray<Selectors>) => Result>;
    <Selectors extends SelectorArray, Result>(selectors: [...Selectors], combiner: (...args: SelectorResultArray<Selectors>) => Result): OutputSelector<Selectors, Result, GetParamsFromSelectors<Selectors>, (...args: SelectorResultArray<Selectors>) => Result>;
}
export declare const createSelector: CreateSelectorFunction;
declare type SelectorsObject = {
    [key: string]: (...args: any[]) => any;
};
export interface StructuredSelectorCreator {
    <SelectorMap extends SelectorsObject>(selectorMap: SelectorMap, selectorCreator?: CreateSelectorFunction): (state: SelectorMap[keyof SelectorMap] extends (state: infer State) => unknown ? State : never) => {
        [Key in keyof SelectorMap]: ReturnType<SelectorMap[Key]>;
    };
    <State, Result = State>(selectors: {
        [K in keyof Result]: Selector<State, Result[K], never>;
    }, selectorCreator?: CreateSelectorFunction): Selector<State, Result, never>;
}
export declare const createStructuredSelector: StructuredSelectorCreator;
